Create starting values for iterative reweighted least squares
Source:R/sgl_irwls.R
make_irls_warmup.RdThis function may be used to create potentially valid starting values for calling [sparsegl()] with a [stats::family()] object. It is not typically necessary to call this function (as it is used internally to create some), but in some cases, especially with custom generalized linear models, it may improve performance.
Arguments
- nobs
Number of observations in the response (or rows in `x`).
- nvars
Number of columns in `x`
- b0
Scalar. Initial value for the intercept.
- beta
Vector. Initial values for the coefficients. Must be length `nvars` (or a scalar).
- r
Vector. Initial values for the deviance residuals. Must be length `nobs` (or a scalar).