| hierNest-package | R Documentation |
Efficient implementation of penalized regression with hierarchical nested parametrization for grouped data. The package provides penalized regression methods that decompose subgroup specific effects into shared global effects, Major subgroup specific effects, and Minor subgroup specific effects, enabling structured borrowing of information across related clinical subgroups. Both lasso and hierarchical overlapping group lasso penalties are supported to encourage sparsity while respecting the nested subgroup structure. Efficient computation is achieved through a modified design matrix representation and a custom majorization minimization algorithm for overlapping group penalties.
Maintainer: Ziren Jiang jian0746@umn.edu
Authors:
Jared Huling huling@umn.edu
Jue Hou hou00123@umn.edu
Lingfeng Huo
Other contributors:
Daniel J. McDonald [contributor]
Xiaoxuan Liang [contributor]
Anibal Solón Heinsfeld [contributor]
Aaron Cohen [contributor]
Yi Yang [contributor]
Hui Zou [contributor]
Jerome Friedman [contributor]
Trevor Hastie [contributor]
Rob Tibshirani [contributor]
Balasubramanian Narasimhan [contributor]
Kenneth Tay [contributor]
Noah Simon [contributor]
Junyang Qian [contributor]
James Yang [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.